<!DOCTYPE TS><TS>
<context>
    <name>QApplication</name>
    <message>
        <source>Executable &apos;%1&apos; requires Qt %2, found Qt %3.</source>
        <translation>Çalıştırılabilir kütük &apos;%1&apos;, Qt %2&apos; ye ihtiyaç duyarken varolan Qt %3.</translation>
    </message>
    <message>
        <source>Incompatible Qt Library Error</source>
        <translation>Uyumsuz Qt kütüphane hatası</translation>
    </message>
</context>
<context>
    <name>QColorDialog</name>
    <message>
        <source>Hu&amp;e:</source>
        <translation>Ren&amp;k:</translation>
    </message>
    <message>
        <source>&amp;Sat:</source>
        <translation>&amp;Doygunluk:</translation>
    </message>
    <message>
        <source>&amp;Val:</source>
        <translation>&amp;Değer:</translation>
    </message>
    <message>
        <source>&amp;Red:</source>
        <translation>K&amp;ırmızı:</translation>
    </message>
    <message>
        <source>&amp;Green:</source>
        <translation>&amp;Yeşil:</translation>
    </message>
    <message>
        <source>Bl&amp;ue:</source>
        <translation>&amp;Mavi:</translation>
    </message>
    <message>
        <source>A&amp;lpha channel:</source>
        <translation>A&amp;lfa oluk:</translation>
    </message>
    <message>
        <source>&amp;Basic colors</source>
        <translation>&amp;Temel renkler</translation>
    </message>
    <message>
        <source>&amp;Custom colors</source>
        <translation>Ki&amp;şisel renkler</translation>
    </message>
    <message>
        <source>&amp;Define Custom Colors &gt;&gt;</source>
        <translation>Kişisel &amp;Renk Tanımla &gt;&gt;</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>&amp;Add to Custom Colors</source>
        <translation>&amp;Kişisel Renklere Ekle</translation>
    </message>
    <message>
        <source>Select color</source>
        <translation>Renk seç</translation>
    </message>
</context>
<context>
    <name>QDialog</name>
    <message>
        <source>What&apos;s This?</source>
        <translation>Bu nedir ?</translation>
    </message>
</context>
<context>
    <name>QErrorMessage</name>
    <message>
        <source>Debug Message:</source>
        <translation>Hata Ayıklama Açıklaması:</translation>
    </message>
    <message>
        <source>Warning:</source>
        <translation>Uyarı:</translation>
    </message>
    <message>
        <source>Fatal Error:</source>
        <translation>Düzeltilemez Hata:</translation>
    </message>
    <message>
        <source>&amp;Show this message again</source>
        <translation>&amp;Bu açıklamayı tekrar göster</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Tamam</translation>
    </message>
</context>
<context>
    <name>QFileDialog</name>
    <message>
        <source>Copy or Move a File</source>
        <translation>Kütük Taşı veya Çogalt</translation>
    </message>
    <message>
        <source>Read: %1</source>
        <translation>Oku: %1</translation>
    </message>
    <message>
        <source>Write: %1</source>
        <translation>Yaz: %1</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tüm Kütükler (*)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>İsim</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Büyüklük</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Çeşit</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Tarih</translation>
    </message>
    <message>
        <source>Attributes</source>
        <translation>Nitelikler</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Look &amp;in:</source>
        <translation>İçine &amp;bak:</translation>
    </message>
    <message>
        <source>File &amp;name:</source>
        <translation>Kütük &amp;ismi:</translation>
    </message>
    <message>
        <source>File &amp;type:</source>
        <translation>Kütük &amp;çeşidi:</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Geri</translation>
    </message>
    <message>
        <source>One directory up</source>
        <translation>Bir üst dizin</translation>
    </message>
    <message>
        <source>Create New Folder</source>
        <translation>Yeni Dizin Oluştur</translation>
    </message>
    <message>
        <source>List View</source>
        <translation>Dizelge Görünüm</translation>
    </message>
    <message>
        <source>Detail View</source>
        <translation>Ayrıntılı Görünüm</translation>
    </message>
    <message>
        <source>Preview File Info</source>
        <translation>Kütük Bilgisi Önizleme</translation>
    </message>
    <message>
        <source>Preview File Contents</source>
        <translation>Kütük İçeriği Önizleme</translation>
    </message>
    <message>
        <source>Read-write</source>
        <translation>Oku-yaz</translation>
    </message>
    <message>
        <source>Read-only</source>
        <translation>Sadece-oku</translation>
    </message>
    <message>
        <source>Write-only</source>
        <translation>Sadece-yaz</translation>
    </message>
    <message>
        <source>Inaccessible</source>
        <translation>Ulaşılamaz</translation>
    </message>
    <message>
        <source>Symlink to File</source>
        <translation>Kütüğe Simgesel Bağlantı</translation>
    </message>
    <message>
        <source>Symlink to Directory</source>
        <translation>Dizine Simgesel Bağlantı</translation>
    </message>
    <message>
        <source>Symlink to Special</source>
        <translation>Özele Simgesel Bağlantı</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Kütük</translation>
    </message>
    <message>
        <source>Dir</source>
        <translation>Dizin</translation>
    </message>
    <message>
        <source>Special</source>
        <translation>Özel</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Farklı Kaydet</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Aç</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Kaydet</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Yeniden Adlandır</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Sil</translation>
    </message>
    <message>
        <source>R&amp;eload</source>
        <translation>&amp;Tekrar Yükle</translation>
    </message>
    <message>
        <source>Sort by &amp;Name</source>
        <translation>İsme Göre &amp;Sırala</translation>
    </message>
    <message>
        <source>Sort by &amp;Size</source>
        <translation>Büyüklüğe &amp;Göre Sırala</translation>
    </message>
    <message>
        <source>Sort by &amp;Date</source>
        <translation>&amp;Tarihe Göre Sırala</translation>
    </message>
    <message>
        <source>&amp;Unsorted</source>
        <translation>&amp;Sırasız</translation>
    </message>
    <message>
        <source>Sort</source>
        <translation>Sırala</translation>
    </message>
    <message>
        <source>Show &amp;hidden files</source>
        <translation>Saklı &amp;Kütükleri Göster</translation>
    </message>
    <message>
        <source>the file</source>
        <translation>kütük</translation>
    </message>
    <message>
        <source>the directory</source>
        <translation>dizin</translation>
    </message>
    <message>
        <source>the symlink</source>
        <translation>simgesel bağlantı</translation>
    </message>
    <message>
        <source>Delete %1</source>
        <translation>%1&apos; i Sil</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Are you sure you wish to delete %1 &quot;%2&quot;?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt; %1 &quot;%2&quot; silmek istediğinizden emin misiniz ?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Evet</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Hayır</translation>
    </message>
    <message>
        <source>New Folder 1</source>
        <translation>Yeni Dizin 1</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Yeni Dizin</translation>
    </message>
    <message>
        <source>New Folder %1</source>
        <translation>Yeni Dizin %1</translation>
    </message>
    <message>
        <source>Find Directory</source>
        <translation>Dizin Bul</translation>
    </message>
    <message>
        <source>Directories</source>
        <translation>Dizinler</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Directory:</source>
        <translation>Dizin:</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>%1
File not found.
Check path and filename.</source>
        <translation>%1
Kütük bulunamadı.
Yolu ve kütük adını denetleyin.</translation>
    </message>
</context>
<context>
    <name>QFont</name>
    <message>
        <source>Latin</source>
        <translation>Latince</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Yunanca</translation>
    </message>
    <message>
        <source>Cyrillic</source>
        <translation>Kiril (eski islav)</translation>
    </message>
    <message>
        <source>Armenian</source>
        <translation>Ermenice</translation>
    </message>
    <message>
        <source>Georgian</source>
        <translation>Gürcüce</translation>
    </message>
    <message>
        <source>Runic</source>
        <translation>Runik (kalın ve koyu yazı)</translation>
    </message>
    <message>
        <source>Ogham</source>
        <translation>Ogham (düz çizgilerden olusan yazı)</translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation>İbranice</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Arapça</translation>
    </message>
    <message>
        <source>Syriac</source>
        <translation>Suriyece</translation>
    </message>
    <message>
        <source>Thaana</source>
        <translation>Thaana</translation>
    </message>
    <message>
        <source>Devanagari</source>
        <translation>Sanskrit</translation>
    </message>
    <message>
        <source>Bengali</source>
        <translation>Bengali</translation>
    </message>
    <message>
        <source>Gurmukhi</source>
        <translation>Gurmukhi</translation>
    </message>
    <message>
        <source>Gujarati</source>
        <translation>Gujarati (bir hindu yazısı)</translation>
    </message>
    <message>
        <source>Oriya</source>
        <translation>Oriya (bir hindu yazısı)</translation>
    </message>
    <message>
        <source>Tamil</source>
        <translation>Tamil (bir hindu yazısı)</translation>
    </message>
    <message>
        <source>Telugu</source>
        <translation>Telugu (bir hindu yazısı)</translation>
    </message>
    <message>
        <source>Kannada</source>
        <translation>Kannada (bir hindu yazısı)</translation>
    </message>
    <message>
        <source>Malayalam</source>
        <translation>Malayalam (bir hindu yazısı)</translation>
    </message>
    <message>
        <source>Sinhala</source>
        <translation>Sinhala</translation>
    </message>
    <message>
        <source>Thai</source>
        <translation>Taylandça</translation>
    </message>
    <message>
        <source>Lao</source>
        <translation>Lao Dili</translation>
    </message>
    <message>
        <source>Tibetan</source>
        <translation>Tibetçe</translation>
    </message>
    <message>
        <source>Myanmar</source>
        <translation>Myanmar</translation>
    </message>
    <message>
        <source>Khmer</source>
        <translation>Khmer</translation>
    </message>
    <message>
        <source>Han</source>
        <translation>Han</translation>
    </message>
    <message>
        <source>Hiragana</source>
        <translation>Hiragana</translation>
    </message>
    <message>
        <source>Katakana</source>
        <translation>Katakana</translation>
    </message>
    <message>
        <source>Hangul</source>
        <translation>Hangul</translation>
    </message>
    <message>
        <source>Bopomofo</source>
        <translation>Bopomofo</translation>
    </message>
    <message>
        <source>Yi</source>
        <translation>Yi</translation>
    </message>
    <message>
        <source>Ethiopic</source>
        <translation>Etyopyaca</translation>
    </message>
    <message>
        <source>Cherokee</source>
        <translation>Cherokee</translation>
    </message>
    <message>
        <source>Canadian Aboriginal</source>
        <translation>Kanada Aborijin</translation>
    </message>
    <message>
        <source>Mongolian</source>
        <translation>Moğolca</translation>
    </message>
    <message>
        <source>Currency Symbols</source>
        <translation>Parasal Simgeler</translation>
    </message>
    <message>
        <source>Letterlike Symbols</source>
        <translation>Harf Benzeri Simgeler</translation>
    </message>
    <message>
        <source>Number Forms</source>
        <translation>Sayı Şekilleri</translation>
    </message>
    <message>
        <source>Mathematical Operators</source>
        <translation>Matematiksel İşlemciler</translation>
    </message>
    <message>
        <source>Technical Symbols</source>
        <translation>Yöntembilimsel Simgeler</translation>
    </message>
    <message>
        <source>Geometric Symbols</source>
        <translation>Geometrik Simgeler</translation>
    </message>
    <message>
        <source>Miscellaneous Symbols</source>
        <translation>Sınıflandırılmamış Simgeler</translation>
    </message>
    <message>
        <source>Enclosed and Square</source>
        <translation>Kapalı ve Kare</translation>
    </message>
    <message>
        <source>Braille</source>
        <translation>Kabartma Yazı</translation>
    </message>
    <message>
        <source>Unicode</source>
        <translation>Unicode</translation>
    </message>
</context>
<context>
    <name>QFontDialog</name>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Harf</translation>
    </message>
    <message>
        <source>Font st&amp;yle</source>
        <translation>Harf &amp;biçimi</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Büyüklük</translation>
    </message>
    <message>
        <source>Effects</source>
        <translation>Etkiler</translation>
    </message>
    <message>
        <source>Stri&amp;keout</source>
        <translation>&amp;Üstü Çizili</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>Altı &amp;Çizili</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation>&amp;Renk</translation>
    </message>
    <message>
        <source>Sample</source>
        <translation>Örnek</translation>
    </message>
    <message>
        <source>Scr&amp;ipt</source>
        <translation>Be&amp;tik</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Select Font</source>
        <translation>Harf Biçimi Seç</translation>
    </message>
</context>
<context>
    <name>QInputDialog</name>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Evet</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Hayır</translation>
    </message>
    <message>
        <source>&amp;Abort</source>
        <translation>&amp;Görevi Bitirmeden İptal</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>&amp;Tekrar Dene</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Görmezden Gel</translation>
    </message>
    <message>
        <source>&lt;h3&gt;About Qt&lt;/h3&gt;&lt;p&gt;This program uses Qt version %1.&lt;/p&gt;&lt;p&gt;Qt is a C++ toolkit for multiplatform GUI &amp;amp; application development.&lt;/p&gt;&lt;p&gt;Qt provides single-source portability across MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, and all major commercial Unix variants.&lt;br&gt;Qt is also available for embedded devices.&lt;/p&gt;&lt;p&gt;Qt is a Trolltech product. See &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; for more information.&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Qt Hakkında&lt;/h3&gt;&lt;p&gt;Bu yazılım, Qt sürümü %1&apos; kullanır.&lt;/p&gt;&lt;p&gt;Qt bir C++ kütüphanesidir ve pek çok farklı sistemde kullanıcı arayüzü (KA) geliştirmek için kullanılır.&lt;/p&gt;&lt;p&gt;Qt &apos;tekil kaynak metni taşınabilirliği&apos; getirir ve MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, ve tüm büyük Unix çeşitleri için kullanılabilir.&lt;br&gt;Qt aynı zamanda gömülü sistemler için de kullanılabilir.&lt;/p&gt;&lt;p&gt;Qt bir Trolltech ürünüdür. Daha fazlabilgi için &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; sayfasını görün.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>QPrintDialog</name>
    <message>
        <source>locally connected</source>
        <translation>yerel olarak bağlı</translation>
    </message>
    <message>
        <source>Aliases: %1</source>
        <translation>Yerine Geçen İsimler: %1</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>bilinmeyen</translation>
    </message>
    <message>
        <source>Unknown Location</source>
        <translation>Bilinmeyen Yer</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Printer settings</source>
        <translation>Yazıcı ayarları</translation>
    </message>
    <message>
        <source>Print in color if available</source>
        <translation>Mümkünse renkli yazdır</translation>
    </message>
    <message>
        <source>Print in grayscale</source>
        <translation>Gri tonlarla yazdır</translation>
    </message>
    <message>
        <source>Print destination</source>
        <translation>Karşı yazıcı</translation>
    </message>
    <message>
        <source>Print to printer:</source>
        <translation>Şu yazıcıya gönder:</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Yazıcı</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Ev Sahibi Bilgisayar</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Yorum</translation>
    </message>
    <message>
        <source>Print to file:</source>
        <translation>Kütüğe yazdır:</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Gözat...</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>Print all</source>
        <translation>Tümünü yazdır</translation>
    </message>
    <message>
        <source>Print range</source>
        <translation>Aralığı yazdır</translation>
    </message>
    <message>
        <source>From page:</source>
        <translation>Şu sayfadan:</translation>
    </message>
    <message>
        <source>To page:</source>
        <translation>Şu sayfaya:</translation>
    </message>
    <message>
        <source>Print first page first</source>
        <translation>İlk sayfayı ilk yazdır</translation>
    </message>
    <message>
        <source>Print last page first</source>
        <translation>Son sayfayı ilk yazdır</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Çoğaltım sayısı:</translation>
    </message>
    <message>
        <source>Paper format</source>
        <translation>Kağıt biçimi</translation>
    </message>
    <message>
        <source>Portrait</source>
        <translation>Dikey sayfa</translation>
    </message>
    <message>
        <source>Landscape</source>
        <translation>Yatay sayfa</translation>
    </message>
    <message>
        <source>A0 (841 x 1189 mm)</source>
        <translation>A0 (841 x 1189 mm)</translation>
    </message>
    <message>
        <source>A1 (594 x 841 mm)</source>
        <translation>A1 (594 x 841 mm)</translation>
    </message>
    <message>
        <source>A2 (420 x 594 mm)</source>
        <translation>A2 (420 x 594 mm)</translation>
    </message>
    <message>
        <source>A3 (297 x 420 mm)</source>
        <translation>A3 (297 x 420 mm)</translation>
    </message>
    <message>
        <source>A4 (210x297 mm, 8.26x11.7 inches)</source>
        <translation>A4 (210x297 mm, 8.26x11.7 inç)</translation>
    </message>
    <message>
        <source>A5 (148 x 210 mm)</source>
        <translation>A5 (148 x 210 mm)</translation>
    </message>
    <message>
        <source>A6 (105 x 148 mm)</source>
        <translation>A6 (105 x 148 mm)</translation>
    </message>
    <message>
        <source>A7 (74 x 105 mm)</source>
        <translation>A7 (74 x 105 mm)</translation>
    </message>
    <message>
        <source>A8 (52 x 74 mm)</source>
        <translation>A8 (52 x 74 mm)</translation>
    </message>
    <message>
        <source>A9 (37 x 52 mm)</source>
        <translation>A9 (37 x 52 mm)</translation>
    </message>
    <message>
        <source>B0 (1000 x 1414 mm)</source>
        <translation>B0 (1000 x 1414 mm)</translation>
    </message>
    <message>
        <source>B1 (707 x 1000 mm)</source>
        <translation>B1 (707 x 1000 mm)</translation>
    </message>
    <message>
        <source>B2 (500 x 707 mm)</source>
        <translation>B2 (500 x 707 mm)</translation>
    </message>
    <message>
        <source>B3 (353 x 500 mm)</source>
        <translation>B3 (353 x 500 mm)</translation>
    </message>
    <message>
        <source>B4 (250 x 353 mm)</source>
        <translation>B4 (250 x 353 mm)</translation>
    </message>
    <message>
        <source>B5 (176 x 250 mm, 6.93x9.84 inches)</source>
        <translation>B5 (176 x 250 mm, 6.93x9.84 inç)</translation>
    </message>
    <message>
        <source>B6 (125 x 176 mm)</source>
        <translation>B6 (125 x 176 mm)</translation>
    </message>
    <message>
        <source>B7 (88 x 125 mm)</source>
        <translation>B7 (88 x 125 mm)</translation>
    </message>
    <message>
        <source>B8 (62 x 88 mm)</source>
        <translation>B8 (62 x 88 mm)</translation>
    </message>
    <message>
        <source>B9 (44 x 62 mm)</source>
        <translation>B9 (44 x 62 mm</translation>
    </message>
    <message>
        <source>B10 (31 x 44 mm)</source>
        <translation>B10 (31 x 44 mm)</translation>
    </message>
    <message>
        <source>C5E (163 x 229 mm)</source>
        <translation>C5E (163 x 229 mm</translation>
    </message>
    <message>
        <source>DLE (110 x 220 mm)</source>
        <translation>DLE (110 x 220 mm)</translation>
    </message>
    <message>
        <source>Executive (7.5x10 inches, 191x254 mm)</source>
        <translation>idari (7.5x10 inç, 191x254 mm)</translation>
    </message>
    <message>
        <source>Folio (210 x 330 mm)</source>
        <translation>Katlı Kagıt (210 x 330 mm)</translation>
    </message>
    <message>
        <source>Ledger (432 x 279 mm)</source>
        <translation>Hesap defteri (432 x 279 mm)</translation>
    </message>
    <message>
        <source>Legal (8.5x14 inches, 216x356 mm)</source>
        <translation>Resmi (8.5x14 inches, 216x356 mm)</translation>
    </message>
    <message>
        <source>Letter (8.5x11 inches, 216x279 mm)</source>
        <translation>Mektup (8.5x11 inç, 216x279 mm)</translation>
    </message>
    <message>
        <source>Tabloid (279 x 432 mm)</source>
        <translation>Küçük gazete (279 x 432 mm)</translation>
    </message>
    <message>
        <source>US Common #10 Envelope (105 x 241 mm)</source>
        <translation>ABD Genel #10 Zarfı (105 x 241 mm)</translation>
    </message>
    <message>
        <source>Setup Printer</source>
        <translation>Yazıcıyı Ayarla</translation>
    </message>
    <message>
        <source>PostScript Files (*.ps);;All Files (*)</source>
        <translation>PostScript Kütükleri (*.ps);;Tüm Kütükler (*)</translation>
    </message>
</context>
<context>
    <name>QWhatsThisButton</name>
    <message>
        <source>What&apos;s this?</source>
        <translation>Bu nedir ?</translation>
    </message>
</context>
</TS>
